@@ -1285,7 +1285,7 @@ sub runsqlcreatecontexttables {
 	my @suffixes;
 	my %objects;
 	my $ret = 1;
-	if ($flowdir eq "incom") { @suffixes = ("seq", "i", "id"); }
+	if ($flowdir eq "incom") { @suffixes = ("seq", "i", "id", "ipk", "idpk"); }
 	else { @suffixes = ("seq", "o", "od", "or", "opk", "odpk", "orpk"); }
 	foreach my $object (@$objects) {
 		 $objects{$object->{object_name}} = $object;
