@@ -15,7 +15,7 @@ CREATE TABLE connector (
 	driverid character varying(20) NOT NULL,
 	port character varying(20),
 	dbidsn character varying(250),
-	ismaster character varying DEFAULT 'MASTER',
+	ismaster character varying(20) DEFAULT 'MASTER',
 	master_id integer,
 	contextid character varying(50),
 	proxy_id integer,
