@@ -19,9 +19,9 @@ CREATE TABLE field (
 	keyposition smallint,
 	localfield character varying(3) DEFAULT 'no' NOT NULL,
 	referto_id integer,
-	xmlnode character varying,
+	xmlnode character varying(50),
 	defaultvalue character varying(250),
-	nullable character varying DEFAULT 'yes',
+	nullable character varying(10) DEFAULT 'yes',
 	Constraint field_pkey Primary Key (object_id)
 );
 
