@@ -17,7 +17,7 @@ CREATE TABLE subflow (
 	dependant character varying(10) DEFAULT 'no',
 	direct character varying(10) DEFAULT 'no',
 	onoutgoerr character varying(20),
-	keepalive character varying DEFAULT 'no',
+	keepalive character varying(10) DEFAULT 'no',
 	mailonerr character varying(10) DEFAULT 'yes',
 	mailonsucc character varying(10) DEFAULT 'no',
 	Constraint subflow_pkey Primary Key (object_id)
