@@ -60,12 +60,20 @@ sub StartSubFlow {
 	$self->MailOnSuccess($subFlow->{mailonerr});
 	$self->MailOnSuccess($subFlow->{mailonsucc});
 	$self->OnErrorAction($subFlow->{onoutgoerr});
+	$self->MyFlowMethod($subFlow->{flowmethod});
 	return (undef) unless($self->CanIRun());
 
 #	$self->OpenExternalDb();
 	$self;
 }
 
+sub MyFlowMethod {
+	my $self = shift;
+
+	if (@_) { $self->{MyFlowMethod} = shift; }
+	$self->{myFlowMethod};
+}
+
 sub MailOnError {
 	my $self = shift;
 
@@ -686,15 +694,18 @@ sub SendMsg {
 	my $e = $@ || "";
 #	print "SENDMSG ==> $ret";
 	if ($ret == 0) {
-		if ($action = $self->UserAlternateAction("step")) { $type = "step"; }
-		elsif ($action = $self->UserAlternateAction("name")) { $type = "name"; }
-		elsif ($action = $self->UserAlternateAction("id")) { $type = "id"; }
-		else { $action = "sendmsgbis"; $type = "usedfor"; }
+		my $method = $self->MyFlowMethod();
+		if ($method = /updins|delins|insupd/) {
+			if ($action = $self->UserAlternateAction("step")) { $type = "step"; }
+			elsif ($action = $self->UserAlternateAction("name")) { $type = "name"; }
+			elsif ($action = $self->UserAlternateAction("id")) { $type = "id"; }
+			else { $action = "sendmsgbis"; $type = "usedfor"; }
 
-		eval {
+			eval {
 			# $ret = $self->ExecuteSendQuery($dbh,"sendmsgbis");
-			$ret = $self->ExecuteSendQuery($dbh,$action, $type);
-		};
+				$ret = $self->ExecuteSendQuery($dbh,$action, $type);
+			};
+		}
 		if ($@) { $e .= " THEN " . $@; }
 		else { $e = undef; }
 #		print " SENDMSGBIS ==> $ret";
