@@ -861,7 +861,7 @@ sub checkredirect {
 		$other->_hiddenvar("_actiondetail", "search");
 		eval { $other->startpage(); };
 		if ($@ and (cafDbg->geterrorn() < 0)) {
-			cafDbg->pusherror("Error while executing startpae " . $@);
+			cafDbg->pusherror("Error while executing startpage " . $@);
 		}
 		$other->displaypage();
 	}
