@@ -83,9 +83,19 @@ function ValidateMenu (imenu, theForm) {
 	var smenu = theForm.s_menu;
 	var ssubmenu = theForm.s_submenu;
 
+	var notyetmenus = new Array ( "tools.patch" );
+
 	var currmenu = smenu[smenu.selectedIndex].value;
 	var currsubmenu = ssubmenu[ssubmenu.selectedIndex].value;
 
+	var mSm = currmenu + "." + currsubmenu;
+	for (var i = 0; i < notyetmenus.length; i++) {
+		if (notyetmenus[i] == mSm) {
+			alert ("This module is not yet ready , Sorry");
+			return;
+		}
+	}
+
 	theForm._currmenu.value = currmenu;
 	theForm._currsubmenu.value = currsubmenu;
 	theForm._nextpage.value = currsubmenu;
@@ -504,7 +514,8 @@ function ResetFields (theFormx) {
 }
 
 function ShowHelp (page) {
-	alert ("Show Help " + myLabel + "  (" + page + ")");
+//	alert ("Show Help " + myLabel + "  (" + page + ")");
+	alert ("Sorry Help is planned and is comming soon");
 }
 
 
